@@ -9,15 +9,18 @@ CGI::Portable::AppMultiScreen - Delegate construction, navigation of hierarchica
 package CGI::Portable::AppMultiScreen;
 require 5.004;
 
-# Copyright (c) 1999-2001, Darren R. Duncan. All rights reserved. This module is
-# free software; you can redistribute it and/or modify it under the same terms as
-# Perl itself.  However, I do request that this copyright information remain
-# attached to the file.  If you modify this module and redistribute a changed
-# version then please attach a note listing the modifications.
+# Copyright (c) 1999-2003, Darren R. Duncan.  All rights reserved.  This module
+# is free software; you can redistribute it and/or modify it under the same terms
+# as Perl itself.  However, I do request that this copyright information and
+# credits remain attached to the file.  If you modify this module and
+# redistribute a changed version then please attach a note listing the
+# modifications.  This module is available "as-is" and the author can not be held
+# accountable for any problems resulting from its use.
 
 use strict;
+use warnings;
 use vars qw($VERSION @ISA);
-$VERSION = '0.46';
+$VERSION = '0.461';
 
 ######################################################################
 
@@ -33,15 +36,15 @@ $VERSION = '0.46';
 
 =head2 Nonstandard Modules
 
-	CGI::Portable 0.46
-	CGI::Portable::AppStatic 0.46 (a superclass)
+	CGI::Portable 0.461
+	CGI::Portable::AppStatic 0.461 (a superclass)
 
 =cut
 
 ######################################################################
 
-use CGI::Portable 0.46;
-use CGI::Portable::AppStatic 0.46;
+use CGI::Portable 0.461;
+use CGI::Portable::AppStatic 0.461;
 @ISA = qw( CGI::Portable::AppStatic );
 
 ######################################################################
@@ -52,6 +55,7 @@ use CGI::Portable::AppStatic 0.46;
 
 	#!/usr/bin/perl
 	use strict;
+	use warnings;
 
 	require CGI::Portable;
 	my $globals = CGI::Portable->new();
@@ -287,7 +291,7 @@ default error screen instead.
 sub set_multi_screen_navigate_delegate_list {
 	my ($self, $globals) = @_;
 	my $rh_prefs = $globals->get_prefs_ref();
-		
+
 	my $user_path_element = $globals->current_user_path_element();
 	$user_path_element ||= $rh_prefs->{$PKEY_DEFAULT_DELEGATE};
 
@@ -296,7 +300,7 @@ sub set_multi_screen_navigate_delegate_list {
 	unless( ref( $delegate ) eq 'HASH' ) {
 		$delegate = $rh_prefs->{$PKEY_UNKNOWN_DELEGATE};
 	}
-	
+
 	if( ref( $delegate ) eq 'HASH' ) {
 		$self->set_multi_screen_dispatch_one_delegate( 
 			$globals, $delegate, $user_path_element );
@@ -355,7 +359,7 @@ a user error, CGI::Portable's error list is not supplemented.
 
 sub set_multi_screen_no_delegate_message {
 	my ($self, $globals) = @_;
-		
+
 	$globals->page_title( '404 Page Not Found' );
 
 	$globals->set_page_body( <<__endquote );
@@ -382,16 +386,21 @@ __END__
 
 =head1 AUTHOR
 
-Copyright (c) 1999-2001, Darren R. Duncan. All rights reserved. This module is
-free software; you can redistribute it and/or modify it under the same terms as
-Perl itself.  However, I do request that this copyright information remain
-attached to the file.  If you modify this module and redistribute a changed
-version then please attach a note listing the modifications.
+Copyright (c) 1999-2003, Darren R. Duncan.  All rights reserved.  This module
+is free software; you can redistribute it and/or modify it under the same terms
+as Perl itself.  However, I do request that this copyright information and
+credits remain attached to the file.  If you modify this module and
+redistribute a changed version then please attach a note listing the
+modifications.  This module is available "as-is" and the author can not be held
+accountable for any problems resulting from its use.
 
 I am always interested in knowing how my work helps others, so if you put this
-module to use in any of your own code then please send me the URL.  Also, if you
-make modifications to the module because it doesn't work the way you need, please
-send me a copy so that I can roll desirable changes into the main release.
+module to use in any of your own products or services then I would appreciate
+(but not require) it if you send me the website url for said product or
+service, so I know who you are.  Also, if you make non-proprietary changes to
+the module because it doesn't work the way you need, and you are willing to
+make these freely available, then please send me a copy so that I can roll
+desirable changes into the main release.
 
 Address comments, suggestions, and bug reports to B<perl@DarrenDuncan.net>.
 
